#line 1 "libxlu_disk_l.c"
#define _GNU_SOURCE

#line 4 "libxlu_disk_l.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define xlu__disk_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer xlu__disk_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define xlu__disk_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer xlu__disk_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define xlu__disk_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer xlu__disk_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define xlu__disk_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string xlu__disk_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define xlu__disk_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes xlu__disk_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define xlu__disk_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer xlu__disk_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define xlu__disk_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer xlu__disk_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define xlu__disk_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state xlu__disk_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define xlu__disk_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer xlu__disk_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define xlu__disk_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state xlu__disk_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define xlu__disk_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state xlu__disk_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define xlu__disk_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack xlu__disk_yyensure_buffer_stack
#endif

#ifdef yylex
#define xlu__disk_yylex_ALREADY_DEFINED
#else
#define yylex xlu__disk_yylex
#endif

#ifdef yyrestart
#define xlu__disk_yyrestart_ALREADY_DEFINED
#else
#define yyrestart xlu__disk_yyrestart
#endif

#ifdef yylex_init
#define xlu__disk_yylex_init_ALREADY_DEFINED
#else
#define yylex_init xlu__disk_yylex_init
#endif

#ifdef yylex_init_extra
#define xlu__disk_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra xlu__disk_yylex_init_extra
#endif

#ifdef yylex_destroy
#define xlu__disk_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy xlu__disk_yylex_destroy
#endif

#ifdef yyget_debug
#define xlu__disk_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug xlu__disk_yyget_debug
#endif

#ifdef yyset_debug
#define xlu__disk_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug xlu__disk_yyset_debug
#endif

#ifdef yyget_extra
#define xlu__disk_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra xlu__disk_yyget_extra
#endif

#ifdef yyset_extra
#define xlu__disk_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra xlu__disk_yyset_extra
#endif

#ifdef yyget_in
#define xlu__disk_yyget_in_ALREADY_DEFINED
#else
#define yyget_in xlu__disk_yyget_in
#endif

#ifdef yyset_in
#define xlu__disk_yyset_in_ALREADY_DEFINED
#else
#define yyset_in xlu__disk_yyset_in
#endif

#ifdef yyget_out
#define xlu__disk_yyget_out_ALREADY_DEFINED
#else
#define yyget_out xlu__disk_yyget_out
#endif

#ifdef yyset_out
#define xlu__disk_yyset_out_ALREADY_DEFINED
#else
#define yyset_out xlu__disk_yyset_out
#endif

#ifdef yyget_leng
#define xlu__disk_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng xlu__disk_yyget_leng
#endif

#ifdef yyget_text
#define xlu__disk_yyget_text_ALREADY_DEFINED
#else
#define yyget_text xlu__disk_yyget_text
#endif

#ifdef yyget_lineno
#define xlu__disk_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno xlu__disk_yyget_lineno
#endif

#ifdef yyset_lineno
#define xlu__disk_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno xlu__disk_yyset_lineno
#endif

#ifdef yyget_column
#define xlu__disk_yyget_column_ALREADY_DEFINED
#else
#define yyget_column xlu__disk_yyget_column
#endif

#ifdef yyset_column
#define xlu__disk_yyset_column_ALREADY_DEFINED
#else
#define yyset_column xlu__disk_yyset_column
#endif

#ifdef yywrap
#define xlu__disk_yywrap_ALREADY_DEFINED
#else
#define yywrap xlu__disk_yywrap
#endif

#ifdef yyalloc
#define xlu__disk_yyalloc_ALREADY_DEFINED
#else
#define yyalloc xlu__disk_yyalloc
#endif

#ifdef yyrealloc
#define xlu__disk_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc xlu__disk_yyrealloc
#endif

#ifdef yyfree
#define xlu__disk_yyfree_ALREADY_DEFINED
#else
#define yyfree xlu__disk_yyfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define xlu__disk_yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyg->yytext_ptr -= yyg->yy_more_len; \
	yyleng = (int) (yy_cp - yyg->yytext_ptr); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 37
#define YY_END_OF_BUFFER 38
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[594] =
    {   0,
       36,   36,   38,   34,   35,   37, 8193,   34,   35,   37,
    16385, 8193,   34,   37,16385,   34,   35,   37,   35,   37,
       34,   35,   37,   34,   35,   37,   34,   35,   37,   34,
       35,   37,   34,   35,   37,   34,   35,   37,   34,   35,
       37,   34,   35,   37,   34,   35,   37,   34,   35,   37,
       34,   35,   37,   34,   35,   37,   34,   35,   37,   34,
       35,   37,   34,   35,   37,   34,   35,   37,   36,   37,
       37,   34,   34, 8193,   34, 8193,   34,16385, 8193,   34,
     8193,   34,   34, 8225,   34,16417,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,

       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       36, 8193,   34, 8193,   34, 8193, 8225,   34, 8225,   34,
     8225,   24,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34, 8225,   34, 8225,
       34, 8225,   24,   34,   34,   29, 8225,   34,16417,   34,
       34,   16,   34,   34,   34,   34,   34,   34,   34,   34,
       34, 8218, 8225,   34,16410,16417,   34,   34,   32, 8225,
       34,16417,   34, 8217, 8225,   34,16409,16417,   34,   34,
       34, 8220, 8225,   34,16412,16417,   34,   34,   34,   34,

       34,   29, 8225,   34,   29, 8225,   34,   29,   34,   29,
     8225,   34,    3,   34,   16,   34,   34,   34,   34,   34,
       31, 8225,   34,16417,   34,   34,   34, 8218, 8225,   34,
     8218, 8225,   34, 8218,   34, 8218, 8225,   34,   34,   32,
     8225,   34,   32, 8225,   34,   32,   34,   32, 8225, 8217,
     8225,   34, 8217, 8225,   34, 8217,   34, 8217, 8225,   34,
       34, 8220, 8225,   34, 8220, 8225,   34, 8220,   34, 8220,
     8225,   34,   34,   11,   34,   34,   29, 8225,   34,   29,
     8225,   34,   29, 8225,   29,   34,   29,   34,    3,   34,
       34,   34,   34,   34,   34,   34,   31, 8225,   34,   31,

     8225,   34,   31,   34,   31, 8225,   34,   34,   30, 8225,
       34,16417, 8218, 8225,   34, 8218, 8225,   34, 8218, 8225,
     8218,   34, 8218,   34,   34,   32, 8225,   34,   32, 8225,
       34,   32, 8225,   32,   34,   32, 8217, 8225,   34, 8217,
     8225,   34, 8217, 8225, 8217,   34, 8217,   34,   34, 8220,
     8225,   34, 8220, 8225,   34, 8220, 8225, 8220,   34, 8220,
       34,   34,   11,   24,   11,    7,   34,   34,   34,   34,
       34,   34,   34,   14,   34,   31, 8225,   34,   31, 8225,
       34,   31, 8225,   31,   34,   31,    2,   34,   30, 8225,
       34,   30, 8225,   34,   30,   34,   30, 8225,   17,   34,

       34,   12,   34,   34,   23,   11,   11,   24,    7,   24,
        7,   34,    8,   34,   34,   34,   34,    6,   34,   14,
       34,    2,   24,    2,   34,   30, 8225,   34,   30, 8225,
       34,   30, 8225,   30,   34,   30,   17,   34,   34,   12,
       24,   12,   34,   27, 8225,   34,16417,   23,   24,   23,
        7,    7,   24,   34,    8,   24,    8,   34,   34,   34,
       34,    6,   24,    6,    6,   24,    6,   24,   34,    2,
        2,   24,   34,   34,   12,   12,   24,   34,   27, 8225,
       34,   27, 8225,   34,   27,   34,   27, 8225,   23,   24,
       34,    8,    8,   24,   34,   34,   18,   19,    6,    6,

       24,    6,    6,   34,   34,   15,   34,   34,   27, 8225,
       34,   27, 8225,   34,   27, 8225,   27,   34,   27,   34,
       34,   34,   18,   24,   18,   19,   24,   19,    6,    6,
       34,   34,   15,   34,   34,   21,    9,   20,   18,   18,
       24,   19,   19,   24,    6,    5,    6,   34,   22,   34,
       21,   24,   21,    9,   24,    9,   20,   24,   20,    4,
        6,    5,    6,   34,   22,   24,   22,   34,   21,   21,
       24,    9,    9,   24,   20,   20,   24,    4,    6,   13,
       34,   22,   22,   24,   10,   13,   34,   10,   24,   10,
       10,   10,   24

    } ;

static const flex_int16_t yy_accept[373] =
    {   0,
        1,    1,    1,    2,    3,    4,    7,   12,   16,   19,
       21,   24,   27,   30,   33,   36,   39,   42,   45,   48,
       51,   54,   57,   60,   63,   66,   69,   71,   72,   73,
       74,   76,   79,   81,   82,   83,   84,   87,   87,   88,
       89,   90,   91,   92,   93,   94,   95,   96,   97,   98,
       99,  100,  101,  102,  103,  104,  105,  106,  107,  108,
      109,  110,  111,  112,  114,  116,  117,  119,  121,  122,
      123,  124,  125,  126,  127,  128,  129,  130,  131,  132,
      133,  134,  135,  136,  137,  138,  139,  140,  141,  142,
      143,  144,  145,  146,  147,  148,  150,  152,  153,  154,

      155,  156,  160,  161,  162,  164,  165,  166,  167,  168,
      169,  170,  171,  172,  177,  178,  179,  183,  184,  189,
      190,  191,  192,  197,  198,  199,  200,  201,  202,  205,
      208,  210,  212,  213,  215,  217,  218,  219,  220,  221,
      225,  226,  227,  228,  231,  234,  236,  238,  239,  240,
      243,  246,  248,  250,  253,  256,  258,  260,  261,  262,
      265,  268,  270,  272,  273,  274,  275,  276,  277,  280,
      283,  285,  287,  288,  289,  291,  292,  293,  294,  295,
      296,  297,  300,  303,  305,  307,  308,  309,  313,  316,
      319,  321,  323,  324,  325,  326,  329,  332,  334,  336,

      337,  340,  343,  345,  347,  348,  349,  350,  353,  356,
      358,  360,  361,  362,  363,  365,  366,  367,  368,  369,
      370,  371,  372,  373,  374,  376,  379,  382,  384,  386,
      387,  388,  389,  392,  395,  397,  399,  401,  402,  403,
      404,  405,  406,  407,  409,  411,  412,  413,  414,  415,
      416,  417,  418,  419,  420,  422,  424,  425,  426,  429,
      432,  434,  436,  437,  439,  440,  442,  443,  444,  448,
      450,  451,  452,  454,  455,  457,  458,  459,  460,  461,
      462,  464,  465,  467,  469,  470,  471,  473,  474,  475,
      476,  478,  479,  482,  485,  487,  489,  491,  492,  493,

      495,  496,  497,  498,  499,  500,  502,  503,  504,  505,
      506,  508,  509,  512,  515,  517,  519,  520,  521,  522,
      523,  525,  526,  528,  529,  530,  531,  532,  533,  535,
      536,  537,  538,  539,  540,  542,  543,  545,  546,  548,
      549,  550,  551,  553,  554,  556,  557,  559,  560,  562,
      564,  565,  567,  568,  569,  570,  572,  573,  575,  576,
      578,  580,  582,  583,  585,  586,  588,  590,  591,  592,
      594,  594
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    4,    5,    1,    1,    6,    6,    7,
        6,    6,    6,    6,    6,    6,    6,    8,    1,    1,
        9,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   10,   11,   12,   13,

       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   19,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[35] =
    {   0,
        1,    1,    2,    3,    1,    1,    1,    1,    4,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[443] =
    {   0,
        0,    0,  936,  935,  937,  932,   33,   36,  940,  940,
       45,   63,   31,   42,   51,   52,  925,   33,   65,   67,
       69,   70,  924,   71,  923,   75,    0,  940,  928,  940,
       91,   95,    0,    0,  104,  921,  113,    0,   91,   99,
      114,   92,  115,   80,  100,   48,  119,  121,  122,   74,
      123,  128,  131,  129,  125,  133,  135,  136,  137,  143,
      138,  145,    0,  157,    0,    0,  168,    0,    0,  926,
      140,  146,  165,  159,  152,  164,  155,  168,  171,  176,
      177,  170,  180,  175,  184,  188,  212,  191,  185,  192,
      193,  194,  219,  212,  199,  230,    0,    0,  940,  195,

      200,  239,  235,  197,  246,  225,  226,  919,  244,  918,
      243,  236,  245,  266,  248,  264,  282,  271,  291,  248,
      270,  254,  300,  279,  296,  302,  288,  303,  311,    0,
      315,    0,  311,  318,  940,  313,  319,  208,  313,  344,
      321,  331,  325,  333,    0,  352,    0,  345,  347,  359,
        0,  361,    0,  368,    0,  370,    0,  322,  366,  379,
        0,  381,    0,  359,  357,  923,  382,  384,  392,    0,
        0,    0,    0,  387,  940,  386,  390,  392,  329,  401,
      397,  409,    0,  417,    0,  399,  412,  426,  429,    0,
        0,    0,    0,  412,  427,  438,    0,    0,    0,    0,

      440,    0,    0,    0,    0,  436,  405,  447,    0,    0,
        0,    0,  438,  443,  922,  940,  921,  442,  450,  449,
      452,  454,  459,  458,  453,  469,    0,    0,    0,    0,
      920,  470,  481,    0,  483,    0,  484,  481,  919,  368,
      467,  495,  918,  940,  917,  940,  488,  916,  479,  490,
      492,  495,  505,  498,  940,  915,  940,  507,  523,    0,
        0,    0,    0,  940,  503,  864,  940,  846,  532,  836,
        0,  824,  940,  516,  796,  940,  513,  530,  536,  538,
      784,  940,  542,  535,  547,  772,  940,  549,  551,  768,
      940,  502,  562,    0,  564,    0,    0,  562,  764,  940,

      544,  557,  760,  752,  744,  940,  552,  568,  571,  568,
      581,  577,  588,    0,    0,    0,    0,  589,  580,  591,
      736,  940,  728,  940,  601,  602,  597,  599,  940,  603,
      720,  712,  700,  672,  940,  665,  940,  610,  656,  603,
      648,  607,  629,  940,  627,  940,  625,  940,  624,  940,
      607,  574,  940,  614,  572,  940,  491,  940,  433,  940,
      940,  622,  389,  940,  303,  940,  261,  940,  204,  940,
      940,  635,  639,  642,  646,  650,  654,  658,  662,  666,
      670,  674,  678,  682,  686,  690,  694,  698,  702,  706,
      710,  714,  718,  722,  726,  730,  734,  738,  742,  746,

      750,  754,  758,  762,  766,  770,  774,  778,  782,  786,
      790,  794,  798,  802,  806,  810,  814,  818,  822,  826,
      830,  834,  838,  842,  846,  850,  854,  858,  862,  866,
      870,  874,  878,  882,  886,  890,  894,  898,  902,  906,
      910,  914
    } ;

static const flex_int16_t yy_def[443] =
    {   0,
      371,    1,  372,  372,  371,  373,  374,  374,  371,  371,
      375,  375,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,  376,  371,  373,  371,
      377,  374,  378,  378,  379,   12,  373,  380,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,  376,  377,  378,  378,  381,  382,  382,  371,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,  379,   12,   12,   12,
       12,   12,   12,   12,   12,  381,  382,  382,  371,   12,

       12,  383,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,  384,   87,   87,  385,   12,  386,   12,
       12,   12,  387,   12,   12,   12,   12,   12,  388,  389,
      383,  389,   12,   12,  371,   87,   12,   12,   12,  390,
       12,   12,   12,  391,  392,  384,  392,   87,   87,  393,
      394,  385,  394,  395,  396,  386,  396,   12,   12,  397,
      398,  387,  398,   12,   12,  399,   12,   12,  388,  389,
      389,  400,  400,   12,  371,   87,   87,   87,   12,   12,
       12,  401,  402,  390,  402,   12,   12,  403,  391,  392,
      392,  404,  404,   87,   87,  393,  394,  394,  405,  405,

      395,  396,  396,  406,  406,   12,   12,  397,  398,  398,
      407,  407,   12,   12,  408,  371,  409,   87,   12,   87,
       87,   87,   12,   87,   12,  401,  402,  402,  410,  410,
      411,   87,  412,  413,  403,  413,   87,   87,  414,   12,
       12,  415,  408,  371,  416,  371,   87,  417,   12,   87,
       87,   87,  418,   87,  371,  419,  371,   87,  412,  413,
      413,  420,  420,  371,   87,  421,  371,   12,  422,  423,
      423,  416,  371,   87,  424,  371,   12,   87,   87,   87,
      425,  371,  425,  425,   87,  419,  371,   87,   87,  421,
      371,   12,  426,  427,  422,  427,  423,   87,  424,  371,

       12,   87,  428,  429,  425,  371,  425,  425,   87,   87,
       87,   12,  426,  427,  427,  430,  430,   87,   12,   87,
      431,  371,  432,  371,  425,  425,   87,   87,  371,   12,
      433,  434,  435,  431,  371,  432,  371,  425,  425,   87,
      436,   12,  437,  371,  438,  371,  439,  371,  425,  371,
       87,  440,  371,   12,  437,  371,  438,  371,  439,  371,
      371,   87,  440,  371,  441,  371,  442,  371,  442,  371,
        0,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,

      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371
    } ;

static const flex_int16_t yy_nxt[975] =
    {   0,
        6,    7,    8,    9,    6,    6,    6,    6,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   17,   17,
       17,   17,   20,   17,   21,   22,   23,   24,   25,   17,
       26,   17,   17,   17,   32,   32,   33,   32,   32,   33,
       36,   34,   36,   42,   34,   29,   29,   29,   30,   35,
       50,   36,   37,   38,   43,   44,   39,   36,   80,   45,
       36,   36,   40,   29,   29,   29,   30,   35,   46,   48,
       37,   38,   41,   47,   36,   49,   36,   53,   36,   36,
       36,   56,   58,   36,   36,   55,   83,   61,   51,   36,
       54,   62,   52,   29,   65,   59,   32,   32,   33,   66,

       36,   36,   71,   34,   29,   29,   29,   30,   36,   36,
       77,   29,   38,   67,   67,   67,   68,   67,   75,   72,
       67,   69,   73,   36,   36,   74,   78,   79,   36,   53,
       36,   36,   36,   87,   36,   76,   84,   36,   36,   85,
       36,   81,   36,   86,   36,   36,   36,   36,   82,   36,
       92,   95,   36,  100,   36,   36,   89,   90,   88,   29,
       65,   36,   91,  101,   36,   66,   90,   93,   36,   94,
       29,   97,  102,   36,   36,  104,   98,   36,  103,   36,
       36,  107,  108,  106,   36,   36,   36,  105,   86,   36,
      109,  110,  111,   36,   36,  114,  112,   36,  117,  119,

       36,   36,   36,   36,   36,  121,   36,  368,   36,   36,
      120,  113,   29,   29,   29,   30,  118,   36,  134,   29,
       38,   36,  127,  115,  116,  122,  123,  125,   36,  126,
      128,  124,   29,   97,   36,   36,  180,  138,   98,  129,
      129,   67,  130,  129,   36,   36,  129,  132,  133,  135,
      136,  140,   36,   36,   36,   36,  142,   36,  137,   35,
       35,  123,   86,   36,  370,  143,  144,  144,   67,  145,
      144,  148,  158,  144,  147,   35,   35,   90,  119,   36,
       36,  149,  150,  150,   67,  151,  150,  159,   36,  150,
      153,  154,  154,   67,  155,  154,  164,   36,  154,  157,

      160,  160,   67,  161,  160,   36,  368,  160,  163,  165,
      166,   36,   36,   29,  170,  167,  168,   29,  172,  171,
       36,  175,   36,  173,   35,   35,  176,   36,   36,  177,
       36,   36,  188,  174,   36,   29,  190,  178,   36,  181,
       36,  191,  223,  179,  182,  182,   67,  183,  182,  186,
      206,  182,  185,  187,   29,  192,   35,   35,   35,   35,
      193,   29,  197,   29,  199,  194,   36,  198,   36,  200,
       29,  202,   29,  204,  195,   36,  203,   36,  205,  268,
      207,   29,  209,   29,  211,  214,  213,  210,  218,  212,
      217,   36,  353,   36,   29,  170,   36,   35,   35,  219,

      171,   35,   35,   35,   35,  224,   36,  231,   36,  225,
       36,   29,  227,  221,   36,  222,  232,  228,  220,   29,
      229,   36,  240,   35,   35,  230,  233,  233,   67,  234,
      233,   29,  190,  233,  236,  237,  348,  191,  238,   35,
       29,  197,   29,  202,  239,   36,  198,   36,  203,   29,
      209,  242,   36,   35,  247,  210,  255,  241,  248,   36,
       35,   35,   36,   35,   35,   35,   35,  253,   36,   35,
       35,   29,  227,  250,  269,  254,   36,  228,  249,  251,
      252,   35,  258,   29,  260,   29,  262,  264,   36,  261,
      265,  263,   35,   35,  346,   35,   35,   70,  271,   35,

       35,   35,   35,   35,   35,  274,   35,   35,  282,   35,
       35,   36,  277,  278,   35,   35,  283,  284,   35,   35,
      279,  285,   36,  280,  288,   29,  260,   35,   35,  289,
      312,  261,  293,  293,   67,  294,  293,  301,  306,  293,
      296,   35,   35,  298,  303,  306,  304,   35,   35,   35,
       35,  309,  308,   36,  307,  282,  302,  319,   35,   35,
       35,   35,   35,  311,   29,  314,   29,  316,   35,   35,
      315,  282,  317,   35,   35,  344,  310,  364,  325,   35,
       35,  318,   35,   35,  329,  320,   36,  328,  332,   36,
       29,  314,   35,   35,  330,  326,  315,  331,  327,  333,

       35,   35,   35,   35,  282,  282,  340,  341,   35,   35,
       35,   35,   36,  282,   35,   35,   36,  351,   35,   35,
      362,  339,  365,   36,  338,  366,  342,  361,  360,  354,
      358,  349,  356,   35,   35,   27,   27,   27,   27,   29,
       29,   29,   31,   31,   31,   31,   36,   36,   36,   36,
       63,  353,   63,   63,   64,   64,   64,   64,   66,  350,
       66,   66,   35,   35,   35,   35,   70,   70,  324,   70,
       96,   96,   96,   96,   98,  322,   98,   98,  131,  131,
      131,  131,  146,  146,  146,  146,  152,  152,  152,  152,
      156,  156,  156,  156,  162,  162,  162,  162,  169,  169,

      169,  169,  171,  348,  171,  171,  184,  184,  184,  184,
      189,  189,  189,  189,  191,  346,  191,  191,  196,  196,
      196,  196,  198,  344,  198,  198,  201,  201,  201,  201,
      203,  337,  203,  203,  208,  208,  208,  208,  210,  335,
      210,  210,  215,  215,  215,  215,  173,  282,  173,  173,
      226,  226,  226,  226,  228,  324,  228,  228,  235,  235,
      235,  235,  193,  322,  193,  193,  200,  276,  200,  200,
      205,  267,  205,  205,  212,  257,  212,  212,  243,  243,
      243,  243,  245,  245,  245,  245,  230,  306,  230,  230,
      256,  256,  256,  256,  259,  259,  259,  259,  261,  300,

      261,  261,  266,  266,  266,  266,  270,  270,  270,  270,
      272,  272,  272,  272,  275,  275,  275,  275,  281,  281,
      281,  281,  286,  286,  286,  286,  263,  246,  263,  263,
      290,  290,  290,  290,  295,  295,  295,  295,  271,  297,
      271,  271,  299,  299,  299,  299,  305,  305,  305,  305,
      313,  313,  313,  313,  315,  292,  315,  315,  321,  321,
      321,  321,  323,  323,  323,  323,  317,  291,  317,  317,
      334,  334,  334,  334,  336,  336,  336,  336,  343,  343,
      343,  343,  345,  345,  345,  345,  347,  347,  347,  347,
      352,  352,  352,  352,  355,  355,  355,  355,  357,  357,

      357,  357,  359,  359,  359,  359,  363,  363,  363,  363,
      367,  367,  367,  367,  369,  369,  369,  369,  287,  276,
      273,  216,  267,  257,  246,  244,  216,  141,  139,   99,
       36,   30,   60,   57,   36,   30,  371,   28,   28,    5,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371
    } ;

static const flex_int16_t yy_chk[975] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    7,    7,    7,    8,    8,    8,
       13,    7,   18,   13,    8,   11,   11,   11,   11,   11,
       18,   14,   11,   11,   13,   14,   11,   46,   46,   14,
       15,   16,   11,   12,   12,   12,   12,   12,   14,   16,
       12,   12,   12,   15,   19,   16,   20,   20,   21,   22,
       24,   22,   24,   50,   26,   21,   50,   26,   19,   44,
       20,   26,   19,   31,   31,   24,   32,   32,   32,   31,

       39,   42,   39,   32,   35,   35,   35,   35,   40,   45,
       44,   35,   35,   37,   37,   37,   37,   37,   42,   39,
       37,   37,   40,   41,   43,   41,   45,   45,   47,   47,
       48,   49,   51,   54,   55,   43,   51,   52,   54,   52,
       53,   48,   56,   53,   57,   58,   59,   61,   49,   71,
       59,   61,   60,   71,   62,   72,   56,   62,   55,   64,
       64,   75,   58,   72,   77,   64,   57,   60,   74,   60,
       67,   67,   73,   76,   73,   75,   67,   78,   74,   82,
       79,   78,   79,   77,   84,   80,   81,   76,   80,   83,
       81,   82,   83,   85,   89,   86,   84,   86,   88,   90,

       88,   90,   91,   92,  100,   92,  104,  369,   95,  101,
       91,   85,   87,   87,   87,   87,   89,  138,  104,   87,
       87,   94,  100,   87,   87,   93,   93,   94,   93,   95,
      101,   93,   96,   96,  106,  107,  138,  107,   96,  102,
      102,  102,  102,  102,  103,  112,  102,  102,  103,  105,
      105,  109,  111,  109,  113,  105,  111,  120,  106,  115,
      115,  122,  113,  122,  367,  112,  114,  114,  114,  114,
      114,  115,  120,  114,  114,  116,  116,  118,  118,  121,
      118,  116,  117,  117,  117,  117,  117,  121,  124,  117,
      117,  119,  119,  119,  119,  119,  124,  127,  119,  119,

      123,  123,  123,  123,  123,  125,  365,  123,  123,  125,
      126,  126,  128,  129,  129,  127,  128,  131,  131,  129,
      133,  134,  139,  131,  136,  136,  136,  134,  137,  136,
      141,  158,  143,  133,  143,  144,  144,  136,  179,  139,
      142,  144,  179,  137,  140,  140,  140,  140,  140,  141,
      158,  140,  140,  142,  146,  146,  148,  148,  149,  149,
      146,  150,  150,  152,  152,  148,  165,  150,  164,  152,
      154,  154,  156,  156,  149,  159,  154,  240,  156,  240,
      159,  160,  160,  162,  162,  165,  164,  160,  168,  162,
      167,  167,  363,  168,  169,  169,  174,  176,  176,  174,

      169,  177,  177,  178,  178,  180,  181,  186,  186,  181,
      180,  182,  182,  177,  207,  178,  187,  182,  176,  184,
      184,  187,  207,  194,  194,  184,  188,  188,  188,  188,
      188,  189,  189,  188,  188,  194,  359,  189,  195,  195,
      196,  196,  201,  201,  206,  206,  196,  213,  201,  208,
      208,  214,  214,  218,  218,  208,  225,  213,  219,  219,
      220,  220,  225,  221,  221,  222,  222,  223,  223,  224,
      224,  226,  226,  220,  241,  224,  241,  226,  219,  221,
      222,  232,  232,  233,  233,  235,  235,  237,  249,  233,
      238,  235,  238,  238,  357,  237,  237,  242,  242,  247,

      247,  250,  250,  251,  251,  247,  252,  252,  253,  254,
      254,  292,  249,  250,  265,  265,  253,  253,  258,  258,
      251,  254,  277,  252,  258,  259,  259,  274,  274,  265,
      292,  259,  269,  269,  269,  269,  269,  277,  284,  269,
      269,  278,  278,  274,  279,  283,  280,  279,  279,  280,
      280,  285,  284,  301,  283,  307,  278,  301,  285,  285,
      288,  288,  289,  289,  293,  293,  295,  295,  302,  302,
      293,  308,  295,  298,  298,  355,  288,  352,  307,  310,
      310,  298,  309,  309,  311,  302,  312,  310,  319,  319,
      313,  313,  311,  311,  312,  308,  313,  318,  309,  320,

      318,  318,  320,  320,  325,  326,  327,  328,  327,  327,
      328,  328,  330,  338,  340,  340,  342,  340,  351,  351,
      351,  326,  354,  354,  325,  362,  330,  349,  347,  342,
      345,  338,  343,  362,  362,  372,  372,  372,  372,  373,
      373,  373,  374,  374,  374,  374,  375,  375,  375,  375,
      376,  341,  376,  376,  377,  377,  377,  377,  378,  339,
      378,  378,  379,  379,  379,  379,  380,  380,  336,  380,
      381,  381,  381,  381,  382,  334,  382,  382,  383,  383,
      383,  383,  384,  384,  384,  384,  385,  385,  385,  385,
      386,  386,  386,  386,  387,  387,  387,  387,  388,  388,

      388,  388,  389,  333,  389,  389,  390,  390,  390,  390,
      391,  391,  391,  391,  392,  332,  392,  392,  393,  393,
      393,  393,  394,  331,  394,  394,  395,  395,  395,  395,
      396,  323,  396,  396,  397,  397,  397,  397,  398,  321,
      398,  398,  399,  399,  399,  399,  400,  305,  400,  400,
      401,  401,  401,  401,  402,  304,  402,  402,  403,  403,
      403,  403,  404,  303,  404,  404,  405,  299,  405,  405,
      406,  290,  406,  406,  407,  286,  407,  407,  408,  408,
      408,  408,  409,  409,  409,  409,  410,  281,  410,  410,
      411,  411,  411,  411,  412,  412,  412,  412,  413,  275,

      413,  413,  414,  414,  414,  414,  415,  415,  415,  415,
      416,  416,  416,  416,  417,  417,  417,  417,  418,  418,
      418,  418,  419,  419,  419,  419,  420,  272,  420,  420,
      421,  421,  421,  421,  422,  422,  422,  422,  423,  270,
      423,  423,  424,  424,  424,  424,  425,  425,  425,  425,
      426,  426,  426,  426,  427,  268,  427,  427,  428,  428,
      428,  428,  429,  429,  429,  429,  430,  266,  430,  430,
      431,  431,  431,  431,  432,  432,  432,  432,  433,  433,
      433,  433,  434,  434,  434,  434,  435,  435,  435,  435,
      436,  436,  436,  436,  437,  437,  437,  437,  438,  438,

      438,  438,  439,  439,  439,  439,  440,  440,  440,  440,
      441,  441,  441,  441,  442,  442,  442,  442,  256,  248,
      245,  243,  239,  231,  217,  215,  166,  110,  108,   70,
       36,   29,   25,   23,   17,    6,    5,    4,    3,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  371
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() (yyg->yy_more_flag = 1)
#define YY_MORE_ADJ yyg->yy_more_len
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "libxlu_disk_l.l"
/* -*- fundamental -*- */
/*
 * libxlu_disk_l.l - parser for disk specification strings
 *
 * Copyright (C) 2011      Citrix Ltd.
 * Author Ian Jackson <ian.jackson@eu.citrix.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; version 2.1 only. with the special
 * exception on linking described in file LICENSE.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 */
/*
 * Parsing the old xm/xend/xl-4.1 disk specs is a tricky problem,
 * because the target string might in theory contain "," which is the
 * delimiter we use for stripping off things on the RHS, and ":",
 * which is the delimiter we use for stripping off things on the LHS.
 *
 * In this parser we do not support such target strings in the old
 * syntax; if the target string has to contain "," or ":" the new
 * syntax's "target=" should be used.
 */

#line 35 "libxlu_disk_l.l"
#include "libxlu_disk_i.h"

#define YY_NO_INPUT

/* The code generated by flex is missing braces in single line expressions and
 * is not properly indented, which triggers the clang misleading-indentation
 * check that has been made part of -Wall since clang 10. In order to safely
 * disable it on clang versions that don't have the diagnostic implemented
 * also disable the unknown option and pragma warning. */
#ifdef __clang__
# pragma clang diagnostic ignored "-Wunknown-pragmas"
# pragma clang diagnostic ignored "-Wunknown-warning-option"
# pragma clang diagnostic ignored "-Wmisleading-indentation"
#endif

/* Some versions of flex have a bug (Fedora bugzilla 612465) which causes
 * it to fail to declare these functions, which it defines.  So declare
 * them ourselves.  Hopefully we won't have to simultaneously support
 * a flex version which declares these differently somehow. */
int xlu__disk_yyget_column(yyscan_t yyscanner);
void xlu__disk_yyset_column(int  column_no, yyscan_t yyscanner);


/*----- useful macros and functions used in actions -----
 * we use macros in the actual rules to keep the actions short
 * and particularly to avoid repeating boilerplate values such as
 * DPC->disk, yytext, etc. */

/* Sets an enum, checking it hasn't already been set to a different value  */
#define DSET(dpc,member,enumname,str,valname) do{			\
	if (dpc->disk->member != LIBXL_DISK_##enumname##_UNKNOWN &&	\
	    dpc->disk->member != LIBXL_DISK_##enumname##_##valname) {	\
	    xlu__disk_err(dpc, str, TOSTRING(member) " respecified");	\
	} else {							\
	    dpc->disk->member = LIBXL_DISK_##enumname##_##valname;	\
	}								\
    }while(0)

/* For actions whose patterns contain '=', finds the start of the value */
#define FROMEQUALS (strchr(yytext,'=')+1)

/* Chops the delimiter off, modifying yytext and yyleng. */
#define STRIP(delim) do{                                                \
	if (yyleng>0 && yytext[yyleng-1]==(delim))                      \
	    yytext[--yyleng] = 0;                                       \
    }while(0)

/* Sets a string value, checking it hasn't been set already. */
#define SAVESTRING(what,loc,val) do{					\
	savestring(DPC, what " respecified", &DPC->disk->loc, (val));	\
    }while(0)
static void savestring(DiskParseContext *dpc, const char *what_respecified,
		       char **update, const char *value) {
    if (*update) {
        if (**update) { xlu__disk_err(dpc,value,what_respecified); return; }
        free(*update); /* do not complain about overwriting empty strings */
    }
    *update = strdup(value);
}

#define DPC dpc /* our convention in lexer helper functions */

/* Sets ->readwrite from the string.  This ought to be an enum, perhaps. */
static void setaccess(DiskParseContext *dpc, const char *str) {
    if (!strcmp(str, "r") || !strcmp(str, "ro")) {
        dpc->disk->readwrite = 0;
    } else if (!strcmp(str, "rw") || !strcmp(str, "w") || !strcmp(str,"")) {
	dpc->disk->readwrite = 1;
    } else {
	xlu__disk_err(dpc,str,"unknown value for access");
    }
}

/* Sets ->format from the string.  IDL should provide something for this. */
static void setformat(DiskParseContext *dpc, const char *str) {
    if      (!strcmp(str,""))       DSET(dpc,format,FORMAT,str,RAW);
    else if (!strcmp(str,"raw"))    DSET(dpc,format,FORMAT,str,RAW);
    else if (!strcmp(str,"qcow"))   DSET(dpc,format,FORMAT,str,QCOW);
    else if (!strcmp(str,"qcow2"))  DSET(dpc,format,FORMAT,str,QCOW2);
    else if (!strcmp(str,"vhd"))    DSET(dpc,format,FORMAT,str,VHD);
    else if (!strcmp(str,"empty"))  DSET(dpc,format,FORMAT,str,EMPTY);
    else if (!strcmp(str,"qed"))    DSET(dpc,format,FORMAT,str,QED);
    else xlu__disk_err(dpc,str,"unknown value for format");
}

/* Sets ->backend from the string.  IDL should provide something for this. */
static void setbackendtype(DiskParseContext *dpc, const char *str) {
    if (     !strcmp(str,"phy"))   DSET(dpc,backend,BACKEND,str,PHY);
    else if (!strcmp(str,"tap"))   DSET(dpc,backend,BACKEND,str,TAP);
    else if (!strcmp(str,"qdisk")) DSET(dpc,backend,BACKEND,str,QDISK);
    else if (!strcmp(str,"standalone")) DSET(dpc,backend,BACKEND,str,STANDALONE);
    else xlu__disk_err(dpc,str,"unknown value for backendtype");
}

/* Sets ->specification from the string.  IDL should provide something for this. */
static void setspecification(DiskParseContext *dpc, const char *str) {
    if      (!strcmp(str,"xen"))    DSET(dpc,specification,SPECIFICATION,str,XEN);
    else if (!strcmp(str,"virtio")) DSET(dpc,specification,SPECIFICATION,str,VIRTIO);
    else xlu__disk_err(dpc,str,"unknown value for specification");
}

/* Sets ->colo-port from the string.  COLO need this. */
static void setcoloport(DiskParseContext *dpc, const char *str) {
    int port = atoi(str);
    if (port) {
       dpc->disk->colo_port = port;
    } else {
	xlu__disk_err(dpc,str,"unknown value for colo_port");
    }
}

#define DEPRECATE(usewhatinstead) /* not currently reported */

/* Handles a vdev positional parameter which includes a devtype. */
static int vdev_and_devtype(DiskParseContext *dpc, char *str) {
    /* returns 1 if it was <vdev>:<devtype>, 0 (doing nothing) otherwise */
    char *colon = strrchr(str, ':');
    if (!colon)
        return 0;

    DEPRECATE("use `devtype=...'");
    *colon++ = 0;
    SAVESTRING("vdev", vdev, str);

    if (!strcmp(colon,"cdrom")) {
        DPC->disk->is_cdrom = 1;
    } else if (!strcmp(colon,"disk")) {
        DPC->disk->is_cdrom = 0;
    } else {
        xlu__disk_err(DPC,colon,"unknown deprecated type");
    }
    return 1;
}

#undef DPC /* needs to be defined differently the actual lexer */
#define DPC ((DiskParseContext*)yyextra)

#line 1227 "libxlu_disk_l.c"

#line 1229 "libxlu_disk_l.c"

#define INITIAL 0
#define LEXERR 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 185 "libxlu_disk_l.l"


#line 188 "libxlu_disk_l.l"
 /*----- the scanner rules which do the parsing -----*/

#line 1511 "libxlu_disk_l.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yyg->yy_more_len = 0;
		if ( yyg->yy_more_flag )
			{
			yyg->yy_more_len = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			yyg->yy_more_flag = 0;
			}
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 372 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 371 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 190 "libxlu_disk_l.l"
{ /* ignore whitespace before parameters */ }
	YY_BREAK
/* ordinary parameters setting enums or strings */
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 194 "libxlu_disk_l.l"
{ STRIP(','); setformat(DPC, FROMEQUALS); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 196 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 1; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 197 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 1; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 198 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 0; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 199 "libxlu_disk_l.l"
{ xlu__disk_err(DPC,yytext,"unknown value for type"); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 201 "libxlu_disk_l.l"
{ STRIP(','); setaccess(DPC, FROMEQUALS); }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 202 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("backend", backend_domname, FROMEQUALS); }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 203 "libxlu_disk_l.l"
{ STRIP(','); setbackendtype(DPC,FROMEQUALS); }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 204 "libxlu_disk_l.l"
{ STRIP(','); setspecification(DPC,FROMEQUALS); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 206 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("vdev", vdev, FROMEQUALS); }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 207 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("script", script, FROMEQUALS); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 208 "libxlu_disk_l.l"
{ DPC->disk->direct_io_safe = 1; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 209 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->discard_enable, true); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 210 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->discard_enable, false); }
	YY_BREAK
/* Note that the COLO configuration settings should be considered unstable.
  * They may change incompatibly in future versions of Xen. */
case 16:
YY_RULE_SETUP
#line 213 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->colo_enable, true); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 214 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->colo_enable, false); }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 215 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("colo-host", colo_host, FROMEQUALS); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 216 "libxlu_disk_l.l"
{ STRIP(','); setcoloport(DPC, FROMEQUALS); }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 217 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("colo-export", colo_export, FROMEQUALS); }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 218 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("active-disk", active_disk, FROMEQUALS); }
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 219 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("hidden-disk", hidden_disk, FROMEQUALS); }
	YY_BREAK
/* the target magic parameter, eats the rest of the string */
case 23:
YY_RULE_SETUP
#line 223 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("target", pdev_path, FROMEQUALS); }
	YY_BREAK
/* unknown parameters */
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 227 "libxlu_disk_l.l"
{ xlu__disk_err(DPC,yytext,"unknown parameter"); }
	YY_BREAK
/* deprecated prefixes */
/* the "/.*" in these patterns ensures that they count as if they
   * matched the whole string, so these patterns take precedence */
case 25:
YY_RULE_SETUP
#line 234 "libxlu_disk_l.l"
{
                    STRIP(':');
                    DPC->had_depr_prefix=1; DEPRECATE("use `[format=]...,'");
                    setformat(DPC, yytext);
                 }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 240 "libxlu_disk_l.l"
{
                    char *newscript;
                    STRIP(':');
                    DPC->had_depr_prefix=1; DEPRECATE("use `script=...'");
                    if (asprintf(&newscript, "block-%s", yytext) < 0) {
                            xlu__disk_err(DPC,yytext,"unable to format script");
                            return 0;
                    }
                    savestring(DPC, "script respecified",
                               &DPC->disk->script, newscript);
                    free(newscript);
                }
	YY_BREAK
case 27:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 253 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 254 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 29:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 255 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 30:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 256 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 31:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 257 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 32:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 258 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 260 "libxlu_disk_l.l"
{
		  xlu__disk_err(DPC,yytext,"unknown deprecated disk prefix");
		  return 0;
		}
	YY_BREAK
/* positional parameters */
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
#line 267 "libxlu_disk_l.l"
{
    STRIP(',');

    if (DPC->err) {
        /* previous errors may just lead to subsequent ones */
    } else if (!DPC->disk->pdev_path) {
        SAVESTRING("target", pdev_path, yytext);
    } else if (!DPC->had_depr_prefix &&
               DPC->disk->format == LIBXL_DISK_FORMAT_UNKNOWN) {
        if (!*DPC->disk->pdev_path && vdev_and_devtype(DPC,yytext)) {
            DPC->disk->format = LIBXL_DISK_FORMAT_EMPTY;
        } else {
            setformat(DPC,yytext);
        }
    } else if (!DPC->disk->vdev) {
        if (!vdev_and_devtype(DPC,yytext))
            SAVESTRING("vdev", vdev, yytext);
    } else if (!DPC->access_set) {
        DPC->access_set = 1;
        setaccess(DPC,yytext);
    } else {
        xlu__disk_err(DPC,yytext,"too many positional parameters");
        return 0; /* don't print any more errors */
    }
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 293 "libxlu_disk_l.l"
{
    BEGIN(LEXERR);
    yymore();
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 297 "libxlu_disk_l.l"
{
    xlu__disk_err(DPC,yytext,"bad disk syntax"); return 0;
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 300 "libxlu_disk_l.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1870 "libxlu_disk_l.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(LEXERR):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 372 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 372 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 371);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 300 "libxlu_disk_l.l"
